################################
# GUI for cca function
################################
"dialog.cca" <- function(show)
{
	op=options()
	options(warn=-1)
#
# Main dialog window with title
#
	tt <- tktoplevel()
	tkwm.title(tt,"cca")	
#
# Variables for text fields
#
	df1var <- tclVar()
	df2var <- tclVar()
	dudioutvar <- tclVar()
	nfvar <- tclVar()
#
# Checkboxes
#
	scannfvar <- tclVar(1)
#
# Frame 1 : object
#
	frame1 <- tkframe(tt, relief="groove", borderwidth=2)
	labh <- tklabel(frame1, bitmap="questhead")
	tkbind(labh, "<Button-1>", function() print(help("cca")))

	df1.entry <- tkentry(frame1, textvariable=df1var)
	dfnr1.label <- tklabel(frame1, width=4)
	dfnc1.label <- tklabel(frame1, width=4)
	df2.entry <- tkentry(frame1, textvariable=df2var)
	dfnr2.label <- tklabel(frame1, width=4)
	dfnc2.label <- tklabel(frame1, width=4)
	dudiout.entry <- tkentry(frame1, textvariable=dudioutvar)
	choose1.but <- tkbutton(frame1, text="Set", command=function() choosedf(df1.entry, dfnr1.label, dfnc1.label))
	choose2.but <- tkbutton(frame1, text="Set", command=function() choosedf(df2.entry, dfnr2.label, dfnc2.label))
	tkgrid(tklabel(frame1,text="Canonical correspondence analysis", foreground="blue"), labh, columnspan=5)
	tkgrid(tklabel(frame1,text="Output dudi name : "), dudiout.entry)
	tkgrid(tklabel(frame1,text="First dataframe name : "), df1.entry, choose1.but, dfnr1.label, dfnc1.label)
	tkgrid(tklabel(frame1,text="Second dataframe name : "), df2.entry, choose2.but, dfnr2.label, dfnc2.label)
	tkpack(frame1, fill = "x")
#
# Frame 2 : number of axes
#
	frame2 <- tkframe(tt, relief="groove", borderwidth=2)
	nf.entry <- tkentry(frame2, textvariable=nfvar, width=4)
	scannf.cbut <- tkcheckbutton(frame2,text="Ask number of axes interactively", variable=scannfvar)
	tkgrid(scannf.cbut, columnspan=2)
	tkgrid(tklabel(frame2,text="Number of axes : "), nf.entry)
	tkpack(frame2, fill = "x")
#
# Local variables
#
	done <- tclVar(0)	# To terminate the dialog
	
################################
# Function to build the command line from dialog widgets
################################
	"build" <- function()
	{
	#
	# Check that the df1 is not empty and get its name
	#
		if (tclvalue(df1var) != "") {
			df1  <- parse(text=tclvalue(df1var))[[1]]
		} else df1 <- NULL
	#
	# Check that the df2 is not empty and get its name
	#
		if (tclvalue(df2var) != "") {
			df2  <- parse(text=tclvalue(df2var))[[1]]
		} else df2 <- NULL
	#
	# If scannf is false, check that nf is not empty and get it
	#
		scannf <- as.logical(tclObj(scannfvar))
		if (!scannf) {
			if (tclvalue(nfvar) != "")
				nf <- parse(text=tclvalue(nfvar))[[1]]
				else nf <- 2
		} else nf <- 2
	#
	# Make the command line
	#
		substitute(cca(df1, df2, scannf, nf))
	}
		
################################
# Function to reset all dialog elements to default values
################################
	"reset" <- function()
	{
		tclvalue(df1var) <- ""
		tclvalue(df2var) <- ""
		tclvalue(dudioutvar) <- ""
		tclvalue(nfvar) <- ""
		tkconfigure(dfnr1.label, text="")
		tkconfigure(dfnc1.label, text="")
		tkconfigure(dfnr2.label, text="")
		tkconfigure(dfnc2.label, text="")
	}
	
################################
# Function to launch computations
################################
	"execcomp" <- function()
	{
	#
	# Check that the output dudi name is not empty and set it
	#
		if (tclvalue(dudioutvar) == "") tkinsert(dudiout.entry, "end", "untitled1")
		dudiout <- parse(text=paste("\"",tclvalue(dudioutvar)[[1]],"\"",sep=""))
	#
	# Build and display the command line so that the user can check it
	#
		cmd <- build()
		if (show) {
			cat("### Command executed via Tk :\n")
			cat(eval(dudiout)," <- ", deparse(build()),sep="")
			cat("\n")
		}
	#
	# Execute the command
	#
		ade4TkGUIFlag <<- 1
		myObject <- eval.parent(cmd)
		assign(eval(dudiout), myObject, pos=1)
		dialog.dudi.display(eval(dudiout))
		rm(ade4TkGUIFlag, envir=.GlobalEnv)
	}
#
# Reset and Submit buttons
#
	reset.but <- tkbutton(tt, text="Reset", command=reset)
	cancel.but <- tkbutton(tt, text="Dismiss", command=function() tkdestroy(tt))
	submit.but <- tkbutton(tt, text="Submit", default="active", command=function() execcomp())

	tkpack(cancel.but, submit.but, reset.but, side="left", expand=1, fill="x")
#
# If window is closed by user, terminate the dialog
#
	tkbind(tt, "<Destroy>", function() tclvalue(done)<-2)
	tkbind(tt, "<KeyPress-Return>", function() execcomp())
	tkbind(tt, "<KeyPress-Escape>", function() tkdestroy(tt))
#
# User closed the window
#
	if(tclvalue(done)=="2") return()
}
