################################
# GUI for discrimin function
################################
"dialog.discrimin" <- function(show)
{
	op=options()
	options(warn=-1)
#
# Main dialog window with title
#
	tt <- tktoplevel()
	tkwm.title(tt,"discrimin")	
#
# Variables for text fields
#
	dudioutvar <- tclVar()
	dudivar <- tclVar()
	facvar <- tclVar()
	nfvar <- tclVar()
#
# Checkboxes
#
	scannfvar <- tclVar(1)
#
# Frame 1 : dudi
#
	frame1 <- tkframe(tt, relief="groove", borderwidth=2)
	labh <- tklabel(frame1, bitmap="questhead")
	tkbind(labh, "<Button-1>", function() print(help("discrimin")))

	dudiout.entry <- tkentry(frame1, textvariable=dudioutvar)
	dudi.entry <- tkentry(frame1, textvariable=dudivar)
	choosedudi.but <- tkbutton(frame1, text="Set", command=function() choosedudi(dudi.entry))
	tkgrid(tklabel(frame1,text="Discriminant analysis", foreground="blue"), labh, columnspan=5)
	tkgrid(tklabel(frame1,text="Output dudi name : "), dudiout.entry)
	tkgrid(tklabel(frame1,text="Input dudi name : "), dudi.entry, choosedudi.but)
	tkpack(frame1, fill = "x")
#
# Frame 2 : Factor
#
	frame2 <- tkframe(tt, relief="groove", borderwidth=2)
	fac.entry <- tkentry(frame2, textvariable=facvar)
	choosefac.but <- tkbutton(frame2, text="Set", command=function() choosefac2(fac.entry, dudi.entry))
	tkgrid(tklabel(frame2,text="Grouping factor : "), fac.entry, choosefac.but)
	tkpack(frame2, fill = "x")
#
# Frame 3 : number of axes
#
	frame3 <- tkframe(tt, relief="groove", borderwidth=2)
	nf.entry <- tkentry(frame3, textvariable=nfvar, width=4)
	scannf.cbut <- tkcheckbutton(frame3,text="Ask number of axes interactively", variable=scannfvar)
	tkgrid(scannf.cbut, columnspan=2)
	tkgrid(tklabel(frame3,text="Number of axes : "), nf.entry)
	tkpack(frame3, fill = "x")
#
# Local variables
#
	done <- tclVar(0)	# To terminate the dialog
	
################################
# Function to build the command line from dialog widgets
################################
	"build" <- function()
	{
	#
	# Check that the dudi is not empty and get its name
	#
		if (tclvalue(dudivar) != "") {
			dudi  <- parse(text=tclvalue(dudivar))[[1]]
		} else dudi <- 0
	#
	# Check that the factor is not empty and get its name
	#
		if (tclvalue(facvar) != "") {
			fac  <- parse(text=tclvalue(facvar))[[1]]
		} else fac <- 0
	#
	# If scannf is false, check that nf is not empty and get it
	#
		scannf <- as.logical(tclObj(scannfvar))
		if (!scannf) {
			if (tclvalue(nfvar) != "")
				nf <- parse(text=tclvalue(nfvar))[[1]]
				else nf <- 2
		} else nf <- 2
	#
	# Make the command line
	#
		substitute(discrimin(dudi, fac, scannf, nf))
	}
		
################################
# Function to reset all dialog elements to default values
################################
	"reset" <- function()
	{
		tclvalue(dudivar)<-""
		tclvalue(nfvar)<-""
		tclvalue(scannfvar)<-"1"
	
	}
	
################################
# Function to launch computations
################################
	"execcomp" <- function()
	{
	#
	# Check that the analysis name is not empty and get it
	#
		if (tclvalue(dudioutvar) == "") tkinsert(dudiout.entry, "end", "untitled1")
		dudiname <- parse(text=paste("\"",tclvalue(dudioutvar)[[1]],"\"",sep=""))
	#
	# Build and display the command line so that the user can check it
	#
		cmd <- build()
		if (show) {
			cat("### Command executed via Tk :\n")
			cat(eval(dudiname)," <- ", deparse(build()),sep="")
			cat("\n")
		}
	#
	# Execute the command
	#
		ade4TkGUIFlag <<- 1
		mydudi <- eval.parent(cmd)
		assign(eval(dudiname), mydudi, pos=1)
		dialog.dudi.display(eval(dudiname))
		rm(ade4TkGUIFlag, envir=.GlobalEnv)
	}
#
# Reset and Submit buttons
#
	reset.but <- tkbutton(tt, text="Reset", command=reset)
	cancel.but <- tkbutton(tt, text="Dismiss", command=function() tkdestroy(tt))
	submit.but <- tkbutton(tt, text="Submit", default="active", command=function() execcomp())

	tkpack(cancel.but, submit.but, reset.but, side="left", expand=1, fill="x")
#
# If window is closed by user, terminate the dialog
#
	tkbind(tt, "<Destroy>", function() tclvalue(done)<-2)
	tkbind(tt, "<KeyPress-Return>", function() execcomp())
	tkbind(tt, "<KeyPress-Escape>", function() tkdestroy(tt))
#
# User closed the window
#
	if(tclvalue(done)=="2") return()
}
