################################
# GUI for dudi.fca function
################################
"dialog.dudi.fca" <- function(show)
{
	op=options()
	options(warn=-1)
#
# Main dialog window with title
#
	tt <- tktoplevel()
	tkwm.title(tt,"dudi.fca")	
#
# Variables for text fields
#
	dudivar <- tclVar()

	dfvar <- tclVar()
	nfvar <- tclVar()
#
# Checkboxes
#
	scannfvar <- tclVar(1)
#
# Frame 1 : dataframe and options
#
	frame1 <- tkframe(tt, relief="groove", borderwidth=2)
	labh <- tklabel(frame1, bitmap="questhead")
	tkbind(labh, "<Button-1>", function() print(help("dudi.fca")))

	dudi.entry <- tkentry(frame1, textvariable=dudivar)
	df.entry <- tkentry(frame1, textvariable=dfvar)
	dfnr.label <- tklabel(frame1, width=4)
	dfnc.label <- tklabel(frame1, width=4)
	choosedf.but <- tkbutton(frame1, text="Set", command=function() choosedf(df.entry, dfnr.label, dfnc.label))
	tkgrid(tklabel(frame1,text="Fuzzy correspondence analysis", foreground="blue"), labh, columnspan=5)
	tkgrid(tklabel(frame1,text="Output dudi name : "), dudi.entry)
	tkgrid(tklabel(frame1,text="Input data frame : "), df.entry, choosedf.but, dfnr.label, dfnc.label)

	tkpack(frame1, fill = "x")
#
# Frame 2 : Number of axes
#
	frame2 <- tkframe(tt, relief="groove", borderwidth=2)
	nf.entry <- tkentry(frame2, textvariable=nfvar, width=4)
	scannf.cbut <- tkcheckbutton(frame2,text="Ask number of axes interactively", variable=scannfvar)
	tkgrid(scannf.cbut, columnspan=2)
	tkgrid(tklabel(frame2,text="Number of axes : "), nf.entry)
	tkpack(frame2, fill = "x")
#
# Local variables
#
	vnr=NULL			# Vector of dataframes row numbers
	vnc=NULL			# Vector of dataframes column numbers
	numi=1				# Number of choosed element
	done <- tclVar(0)	# To terminate the dialog

################################
# Function to build the command line from dialog widgets
################################
	"build" <- function()
	{
	#
	# Check that the data frame is not empty and get its name
	#
		if (tclvalue(dfvar) != "") {
			df  <- parse(text=tclvalue(dfvar))[[1]]
		} else df <- 0
	#
	# If scannf is false, check that nf is not empty and get it
	#
		scannf <- as.logical(tclObj(scannfvar))
		if (!scannf) {
			if (tclvalue(nfvar) != "")
				nf <- parse(text=tclvalue(nfvar))[[1]]
				else nf <- 2
		} else nf <- 2
	#
	# Make the command line
	#
		substitute(dudi.fca(df, scannf=scannf, nf=nf))
	}
		
################################
# Function to reset all dialog elements to default values
################################
	"reset" <- function()
	{
		tclvalue(dfvar)<-""
		tclvalue(nfvar)<-""
		tclvalue(scannfvar)<-"1"
		tkconfigure(dfnr.label, text="")
		tkconfigure(dfnc.label, text="")
	
	}
	
################################
# Function to launch computations
################################
	"execcomp" <- function()
	{
	#
	# Check that the analysis name is not empty and get it
	#
		if (tclvalue(dudivar) == "") tkinsert(dudi.entry, "end", "untitled1")
		dudiname <- parse(text=paste("\"",tclvalue(dudivar)[[1]],"\"",sep=""))
	#
	# Build and display the command line so that the user can check it
	#
		cmd <- build()
		if (show) {
			cat("### Command executed via Tk :\n")
			cat(eval(dudiname)," <- ", deparse(build()),sep="")
			cat("\n")
		}
	#
	# Execute the command
	#
		ade4TkGUIFlag <<- 1
		mydudi <- eval.parent(cmd)
		assign(eval(dudiname), mydudi, pos=1)
		dialog.dudi.display(eval(dudiname))
		rm(ade4TkGUIFlag, envir=.GlobalEnv)
	}

#
# Reset and Submit buttons
#
	reset.but <- tkbutton(tt, text="Reset", command=reset)
	cancel.but <- tkbutton(tt, text="Dismiss", command=function() tkdestroy(tt))
	submit.but <- tkbutton(tt, text="Submit", default="active", command=function() execcomp())

	tkpack(cancel.but, submit.but, reset.but, side="left", expand=1, fill="x")
#
# If window is closed by user, terminate the dialog
#
	tkbind(tt, "<Destroy>", function() tclvalue(done)<-2)
	tkbind(tt, "<KeyPress-Return>", function() execcomp())
	tkbind(tt, "<KeyPress-Escape>", function() tkdestroy(tt))
#
# User closed the window
#
	if(tclvalue(done)=="2") return()
}

