################################
# GUI for dudi.pca function
################################
"dialog.dudi.pca" <- function(show)
{
	op=options()
	options(warn=-1)
#
# Main dialog window with title
#
	tt <- tktoplevel()
	tkwm.title(tt,"dudi.pca")	
#
# Variables for text fields
#
	dudivar <- tclVar()

	dfvar <- tclVar()
	rwvar <- tclVar()
	cwvar <- tclVar()
	nfvar <- tclVar()
#
# Checkboxes
#
	centervar <- tclVar(1)
	scalevar <- tclVar(1)
	scannfvar <- tclVar(1)
	urwvar <- tclVar(1)
	ucwvar <- tclVar(1)
#
# Frame 1 : dataframe and options
#
	frame1 <- tkframe(tt, relief="groove", borderwidth=2)
	frame11 <- tkframe(frame1, relief="groove", borderwidth=2)
	frame12 <- tkframe(frame1, relief="groove", borderwidth=2)

	labh <- tklabel(frame11, bitmap="questhead")
	tkbind(labh, "<Button-1>", function() print(help("dudi.pca")))

	dudi.entry <- tkentry(frame11, textvariable=dudivar)
	df.entry <- tkentry(frame11, textvariable=dfvar)
	dfnr.label <- tklabel(frame11, width=4)
	dfnc.label <- tklabel(frame11, width=4)
	choosedf.but <- tkbutton(frame11, text="Set", command=function() choosedf(df.entry, dfnr.label, dfnc.label))
	tkgrid(tklabel(frame11,text="Principal component analysis", foreground="blue"), labh, columnspan=5)
	tkgrid(tklabel(frame11,text="Output dudi name : "), dudi.entry)
	tkgrid(tklabel(frame11,text="Input data frame : "), df.entry, choosedf.but, dfnr.label, dfnc.label)
	
	center.cbut <- tkcheckbutton(frame12,text="Center", variable=centervar)
	scale.cbut <- tkcheckbutton(frame12,text="Scale", variable=scalevar)
	tkgrid(center.cbut, scale.cbut)
	
	tkpack(frame11, frame12, fill="x")
	tkpack(frame1, fill = "x")
#
# Frame 2 : Number of axes
#
	frame2 <- tkframe(tt, relief="groove", borderwidth=2)
	nf.entry <- tkentry(frame2, textvariable=nfvar, width=4)
	scannf.cbut <- tkcheckbutton(frame2,text="Ask number of axes interactively", variable=scannfvar)
	tkgrid(scannf.cbut, columnspan=2)
	tkgrid(tklabel(frame2,text="Number of axes : "), nf.entry)
	tkpack(frame2, fill = "x")
#
# Frame 3 : Row weights
#
	frame3 <- tkframe(tt, relief="groove", borderwidth=2)
	rw.entry <- tkentry(frame3, textvariable=rwvar)
	chooserw.but <- tkbutton(frame3, text="Set", command=function() chooserw(frame3, dfnr.label, rw.entry, urwvar))
	rwl.cbut <- tkcheckbutton(frame3,text="Uniform row weights", variable=urwvar)
	tkgrid(rwl.cbut, columnspan=2)
	tkgrid(tklabel(frame3,text="Row weights : "), rw.entry, chooserw.but)
	tkpack(frame3, fill = "x")
#
# Frame 4 : Col. weights
#	
	frame4 <- tkframe(tt, relief="groove", borderwidth=2)
	cw.entry <- tkentry(frame4, textvariable=cwvar)
	choosecw.but <- tkbutton(frame4, text="Set", command=function() choosecw(frame4, dfnc.label, cw.entry, ucwvar))
	cwl.cbut <- tkcheckbutton(frame4,text="Uniform col. weights", variable=ucwvar)
	tkgrid(cwl.cbut, columnspan=2)
	tkgrid(tklabel(frame4,text="Column weights : "), cw.entry, choosecw.but)
	tkpack(frame4, fill = "x")
#
# Local variables
#
	vnr=NULL			# Vector of dataframes row numbers
	vnc=NULL			# Vector of dataframes column numbers
	numi=1				# Number of choosed element
	done <- tclVar(0)	# To terminate the dialog
	
################################
# Function to build the command line from dialog widgets
################################
	"build" <- function()
	{
	#
	# Check that the data frame is not empty and get its name
	#
		if (tclvalue(dfvar) != "") {
			df  <- parse(text=tclvalue(dfvar))[[1]]
		} else df <- 0
	#
	# Get center and scale checkboxes state
	#
		center <- as.logical(tclObj(centervar))
		scale <- as.logical(tclObj(scalevar))
	#
	# If scannf is false, check that nf is not empty and get it
	#
		scannf <- as.logical(tclObj(scannfvar))
		if (!scannf) {
			if (tclvalue(nfvar) != "")
				nf <- parse(text=tclvalue(nfvar))[[1]]
				else nf <- 2
		} else nf <- 2
	#
	# Get row and column weighting checkboxes state
	#
		rwl <- as.logical(tclObj(urwvar))
		cwl <- as.logical(tclObj(ucwvar))
	#
	# Check that row and column weights text fields are not empty and get them
	#
		if (tclvalue(rwvar) != "") rw <- parse(text=tclvalue(rwvar))[[1]]
		if (tclvalue(cwvar) != "") cw <- parse(text=tclvalue(cwvar))[[1]]
	#
	# Make the command line
	#
		if (rwl && cwl) substitute(dudi.pca(df, center=center, scale=scale, scannf=scannf, nf=nf))
		else if (rwl && !cwl) substitute(dudi.pca(df, col.w = cw, center=center, scale=scale, scannf=scannf, nf=nf))
		else if (!rwl && cwl) substitute(dudi.pca(df, row.w = rw, center=center, scale=scale, scannf=scannf, nf=nf))
		else if (!rwl && !cwl) substitute(dudi.pca(df, row.w = rw, col.w = cw, center=center, scale=scale, scannf=scannf, nf=nf))
	}
		
################################
# Function to reset all dialog elements to default values
################################
	"reset" <- function()
	{
		tclvalue(dfvar)<-""
		tclvalue(rwvar)<-""
		tclvalue(cwvar)<-""
		tclvalue(nfvar)<-""
		tclvalue(centervar)<-"1"
		tclvalue(scalevar)<-"1"
		tclvalue(scannfvar)<-"1"
		tclvalue(urwvar)<-"1"
		tclvalue(ucwvar)<-"1"
		tkconfigure(dfnr.label, text="")
		tkconfigure(dfnc.label, text="")
	
	}
	
################################
# Function to launch computations
################################
	"execcomp" <- function()
	{
	#
	# Check that the analysis name is not empty and get it
	#
		if (tclvalue(dudivar) == "") tkinsert(dudi.entry, "end", "untitled1")
		dudiname <- parse(text=paste("\"",tclvalue(dudivar)[[1]],"\"",sep=""))
	#
	# Build and display the command line so that the user can check it
	#
		cmd <- build()
		if (show) {
			cat("### Command executed via Tk :\n")
			cat(eval(dudiname)," <- ", deparse(build()),sep="")
			cat("\n")
		}
	#
	# Execute the command
	#
		ade4TkGUIFlag <<- 1
		mydudi <- eval.parent(cmd)
		assign(eval(dudiname), mydudi, pos=1)
		dialog.dudi.display(eval(dudiname))
		rm(ade4TkGUIFlag, envir=.GlobalEnv)
	}
#
# Reset and Submit buttons
#
	reset.but <- tkbutton(tt, text="Reset", command=reset)
	cancel.but <- tkbutton(tt, text="Dismiss", command=function() tkdestroy(tt))
	submit.but <- tkbutton(tt, text="Submit", default="active", command=function() execcomp())

	tkpack(cancel.but, submit.but, reset.but, side="left", expand=1, fill="x")
#
# If window is closed by user, terminate the dialog
#
	tkbind(tt, "<Destroy>", function() tclvalue(done)<-2)
	tkbind(tt, "<KeyPress-Return>", function() execcomp())
	tkbind(tt, "<KeyPress-Escape>", function() tkdestroy(tt))
#
# User closed the window
#
	if(tclvalue(done)=="2") return()
}
